@@ -4,9 +4,9 @@ from typing import Dict, Any
 
 _package_data: Dict[str, Any] = dict(
     full_package_name='ryd',
-    version_info=(0, 7, 0),
-    __version__='0.7.0',
-    version_timestamp='2022-03-05 19:24:30',
+    version_info=(0, 7, 1),
+    __version__='0.7.1',
+    version_timestamp='2022-03-07 07:34:42',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     description='Ruamel Yaml Doc preprocessor (pronounced: /rɑɪt/ like the verb "write")',
@@ -86,7 +86,7 @@ _cligen_data = """\
   - !Arg [file, nargs: +, !Help files to process]
   - !Help clean output files for .ryd files
 - roundtrip:
-  - !Opt [oitnb, !Action store_true, !Help apply oitnb to !python documents]
+  # - !Opt [formatter, f, nargs: +, !Help 'formatter specification (tag cmd [option, ...])']
   - !Arg [file, nargs: +, !Help files to process]
   - !Help roundtrip .ryd file, updating sections
 - from-rst:
