@@ -7,7 +7,7 @@ import subprocess
 import datetime
 from typing import Optional, Any, Union, Dict, List, TextIO
 from ruamel.yaml import YAML
-from ruamel.yaml.comments import TaggedScalar
+from ruamel.yaml.comments import TaggedScalar, CommentedSeq, CommentedMap
 from ruamel.yaml.scalarstring import LiteralScalarString
 from ruamel.std.pathlib import Path
 from ryd.ryd import RYD, RydExecError
@@ -66,9 +66,10 @@ class RstCode:
         self.typ = typ
 
     def dump(self, fp: TextIO) -> None:
+        """RST code blocks are indented, but don't add indentation to empty lines"""
         t = ' ' + self.typ if self.typ else ''
-        fp.write(f'\n.. code::{t}\n\n  ')
-        fp.write('\n  '.join(self.s.splitlines()))
+        fp.write(f'\n.. code::{t}\n')
+        fp.write(''.join(('\n  ' if z else '\n') + z for z in self.s.splitlines()))
         fp.write('\n\n')
 
 
@@ -81,6 +82,35 @@ class RestructuredTextConvertor2(Convertor_0_2):
         self.last_code = False
         self.ofp: Union[TextIO, None] = None
 
+    def roundtrip(self, d: Any, src: bytes) -> bool:
+        m = None
+        if isinstance(d, TaggedScalar):
+            tag, fun = self.get_tag(d)
+            typ = self.get_instance(tag)
+            if fun is not None:
+                try:
+                    m = getattr(typ, 'roundtrip_' + fun, None)
+                except AttributeError:
+                    pass
+            if m is None:
+                m = getattr(typ, 'roundtrip', None)
+        if m is not None:
+            tl, rest = src.split(b'\n', 1)
+            res = m(rest)
+            if res is not None:
+                self.output.append(tl + b'\n' + res)
+                return True
+        self.output.append(src)
+        return True
+
+    def roundtrip_write(self, p: Path, yaml: YAML, cx: Any) -> None:
+        print('roundtrip writing', p)
+        with p.open('wb') as fp:
+            yaml.dump(cx, fp)
+            for x in self.output:
+                fp.write(x)
+        # print((b''.join(self.output)).decode('utf-8'), self._out)
+
     def check(self) -> bool:
         if (
             not self._ryd._args.force
@@ -170,6 +200,19 @@ class RestructuredTextConvertor2(Convertor_0_2):
                 self._line = self._yaml.reader.line - s.count('\n') + 1
                 self.check_backquotes(s)
                 self.add_text(s)
+            elif isinstance(d, (CommentedSeq, CommentedMap)):
+                try:
+                    tag, fun = self.get_tag(d)
+                    typ = self.get_instance(tag)
+                    if fun is not None:
+                        try:
+                            getattr(typ, fun)(d)
+                        except AttributeError:
+                            typ._unknown(fun, d)
+                    else:
+                        typ(d)
+                except RydExecError:
+                    rst_ok = False
             else:
                 print('<<<<<<<<<<<<<<<<<< d', type(d), d.value)
             if not rst_ok:
